======
csvviz
======


.. .. image:: https://img.shields.io/pypi/v/csvviz.svg
..         :target: https://pypi.python.org/pypi/csvviz

.. .. image:: https://img.shields.io/travis/dannguyen/csvviz.svg
..         :target: https://travis-ci.com/dannguyen/csvviz

.. .. image:: https://readthedocs.org/projects/csvviz/badge/?version=latest
..         :target: https://csvviz.readthedocs.io/en/latest/?badge=latest
..         :alt: Documentation Status


Create visualizations from CSV files and the command line


Current status
--------------

Nothing to see here, just a random idea related to another side-project library that I'm struggling to make :D



* Free software: MIT license
* Documentation: https://csvviz.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage



Dev instructions
----------------

To install on your own machine for development::

    $ make install



(note to self) To publish on pypi::

    $ make release
